@@ -2,3 +2,6 @@ from toapi.api import Api
 from toapi.item import Item
 from toapi.log import logger
 from toapi.selector import XPath, Regex, Css
+from toapi.settings import Settings
+
+__version__ = '0.2.11'
